@@ -3,7 +3,7 @@
   Backend for Asymptote files
   Contributed by: John Bowman
 
-  Copyright (C) 1993 - 2018 Wolfgang Glunz, wglunz35_AT_geocities.com
+  Copyright (C) 1993 - 2019 Wolfgang Glunz, wglunz35_AT_geocities.com
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,7 +30,9 @@
 #include I_stdio
 #include I_stdlib
 
+#ifndef OS_WIN32_WCE
 #include <sys/stat.h>
+#endif
 
 #ifndef FLT_MAX
 #include <math.h>				// Need definition of FLT_MAX
@@ -41,6 +43,8 @@
 #include <ctype.h>				// Need definition of ispunct()
 #include <sstream>
 
+
+
 #if !(defined(unix) || defined(__unix__) || defined(_unix) || defined(__unix) || defined(__EMX__) || defined (NetBSD)  )
 #define LINE_MAX 2048			// for MSVC
 #endif
@@ -66,7 +70,7 @@ drvASY::derivedConstructor(drvASY):
   // Output copyright information
   outf << "// Converted from PostScript(TM) to Asymptote by pstoedit\n"
        << "// Asymptote 1.00 (or later) backend contributed by John Bowman\n"
-       << "// pstoedit is Copyright (C) 1993 - 2018 Wolfgang Glunz"
+       << "// pstoedit is Copyright (C) 1993 - 2019 Wolfgang Glunz"
        << " <wglunz35_AT_pstoedit.net>\n\n";
 	
   outf << "import pstoedit;" << endl;
@@ -139,6 +143,7 @@ void drvASY::print_coords()
 	  } else
 	    outf << "fill(";
 	}
+      // fall through
       case lineto:
 	{
 	  const Point & p = elem.getPoint(0);
@@ -210,6 +215,7 @@ void drvASY::print_coords()
       case moveto:
 	if(!withinpath) outf << "draw(";
         // coverity[fallthrough]
+        // fall through
       case lineto:
 	{
 	  const Point & p = elem.getPoint(0);
@@ -411,7 +417,7 @@ void drvASY::show_text(const TextInfo & textinfo)
   if(quote) outf << "\"";
   if(texify) outf << ")";
   if(prevFontAngle != 0.0) outf << ")";
-  outf << ",(" << textinfo.x << ',' << textinfo.y << "),align,textpen);" 
+  outf << ",(" << textinfo.x() << ',' << textinfo.y() << "),align,textpen);" 
        << endl;
 }
 
