@@ -5,7 +5,7 @@
    Backend for Context Free Design Grammar files
    Contributed by: Scott Pakin <scott+ps2ed_AT_pakin.org>
   
-   Copyright (C) 1993 - 2018 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2019 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ public:
 
 	derivedConstructor(drvCFDG);
 
-	~drvCFDG(); // Destructor
+	~drvCFDG() override; // Destructor
 	class DriverOptions : public ProgramOptions {
 	public:
 		DriverOptions() 
