@@ -7,7 +7,7 @@
    drvSAMPL.cpp : This file is part of pstoedit
    Skeleton for the implementation of new backends
 
-   Copyright (C) 1993 - 2018 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2019 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ drvRIB::~drvRIB()
 	// driver specific deallocations
 	// and writing of trailer to output file
 	outf << "AttributeEnd" << endl;
-	options=0;
+	options=nullptr;
 }
 
 void drvRIB::print_coords()
